==> haskell-puresat-0.1-3.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-puresat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-internal
version:              0.1
package-name:         puresat
lib-name:             internal
id:                   puresat-0.1-E1cZ9Hy0yZu8R8OW6h4fuw-internal
key:                  puresat-0.1-E1cZ9Hy0yZu8R8OW6h4fuw-internal
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  645e8d9e0f09eb023d6c8ac6ed0888fe
exposed-modules:
    PureSAT.Assert PureSAT.Base PureSAT.Boost PureSAT.Clause2
    PureSAT.LBool PureSAT.LCG PureSAT.Level PureSAT.LitSet
    PureSAT.LitTable PureSAT.LitVar PureSAT.Main
    PureSAT.PartialAssignment PureSAT.Prim PureSAT.Satisfied
    PureSAT.SparseMaxHeap PureSAT.SparseSet PureSAT.Stats PureSAT.Trail
    PureSAT.Utils PureSAT.VarSet PureSAT.Vec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-E1cZ9Hy0yZu8R8OW6h4fuw-internal
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-dimacs
version:              0.1
package-name:         puresat
lib-name:             dimacs
id:                   puresat-0.1-83XXDJnmAvHBAEfG1ze927-dimacs
key:                  puresat-0.1-83XXDJnmAvHBAEfG1ze927-dimacs
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  c440c5ce362ebb582ccc035388356299
exposed-modules:      PureSAT.DIMACS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-83XXDJnmAvHBAEfG1ze927-dimacs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 parsec-3.1.16.1
    puresat-0.1-E1cZ9Hy0yZu8R8OW6h4fuw-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 puresat
version:              0.1
visibility:           public
id:                   puresat-0.1-5gfK6vpja8QCEiegj8pGS
key:                  puresat-0.1-5gfK6vpja8QCEiegj8pGS
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  0822d0f69579241fcc55355892b52781
exposed:              True
exposed-modules:      Control.Monad.SAT PureSAT
hidden-modules:       EST
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-5gfK6vpja8QCEiegj8pGS
depends:
    base-4.18.2.1 containers-0.6.7
    puresat-0.1-E1cZ9Hy0yZu8R8OW6h4fuw-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puresat-0.1-4-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-puresat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-internal
version:              0.1
package-name:         puresat
lib-name:             internal
id:                   puresat-0.1-97PQ5uyzFMm151MUHiZ0Hk-internal
key:                  puresat-0.1-97PQ5uyzFMm151MUHiZ0Hk-internal
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  7d61aadfba2998da6b4c0e7a92ecf3ca
exposed-modules:
    PureSAT.Assert PureSAT.Base PureSAT.Boost PureSAT.Clause2
    PureSAT.LBool PureSAT.LCG PureSAT.Level PureSAT.LitSet
    PureSAT.LitTable PureSAT.LitVar PureSAT.Main
    PureSAT.PartialAssignment PureSAT.Prim PureSAT.Satisfied
    PureSAT.SparseMaxHeap PureSAT.SparseSet PureSAT.Stats PureSAT.Trail
    PureSAT.Utils PureSAT.VarSet PureSAT.Vec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-97PQ5uyzFMm151MUHiZ0Hk-internal
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-dimacs
version:              0.1
package-name:         puresat
lib-name:             dimacs
id:                   puresat-0.1-9Z5Xg8uVh9F16KiIw1lnu1-dimacs
key:                  puresat-0.1-9Z5Xg8uVh9F16KiIw1lnu1-dimacs
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  fb74aace229b0a1ef5996234abba746e
exposed-modules:      PureSAT.DIMACS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-9Z5Xg8uVh9F16KiIw1lnu1-dimacs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 parsec-3.1.16.1
    puresat-0.1-97PQ5uyzFMm151MUHiZ0Hk-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 puresat
version:              0.1
visibility:           public
id:                   puresat-0.1-FSDiV5i4EbG4NhR6TXyjag
key:                  puresat-0.1-FSDiV5i4EbG4NhR6TXyjag
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  63e8e37d12a9d2533f4e6419b29d3f5a
exposed:              True
exposed-modules:      Control.Monad.SAT PureSAT
hidden-modules:       EST
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-FSDiV5i4EbG4NhR6TXyjag
depends:
    base-4.18.2.1 containers-0.6.7
    puresat-0.1-97PQ5uyzFMm151MUHiZ0Hk-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
